pub struct InputConfig {
pub max_queued_incoming: u16,
pub acknowledge_all_data: bool,
pub data_ack_window: u16,
pub max_ack_delay: Duration,
}Expand description
Configuration controlling the input channel’s behaviour.
Fields
max_queued_incoming: u16Maximum number of incoming reliable data packets that may be stashed.
acknowledge_all_data: boolWhether every data packet is acknowledged individually.
data_ack_window: u16The acknowledgement window used to decide when to send an AcknowledgeAll.
max_ack_delay: DurationMaximum delay before acknowledging incoming reliable data sequences.