Constant values and defaults used by this implementation of the SOE protocol.
Constants
- CRC_
LENGTH - The default number of bytes used to store the CRC check value of a packet.
- DEFAULT_
SESSION_ HEARTBEAT_ AFTER - The default duration after which to send a heartbeat, if no contextual packets have been received within the interval.
- DEFAULT_
SESSION_ INACTIVITY_ TIMEOUT - The default duration after which to consider a session inactive, if no contextual packets have been received within the interval.
- DEFAULT_
UDP_ LENGTH - The default maximum packet (UDP) length.
- MULTI_
DATA_ INDICATOR - The byte sequence that indicates a reliable data packet is carrying bundled (“multi”) data.
- SOE_
PROTOCOL_ VERSION - The implemented version of the SOE protocol.