pub enum Error {
BufferTooShort {
needed: usize,
available: usize,
},
OutOfRange(String),
Zlib(Error),
}Expand description
Errors that can occur while encoding, decoding or processing SOE protocol data.
Variants
BufferTooShort
A buffer was too short to read or write the expected data.
OutOfRange(String)
A value did not fit within the expected bounds.
Zlib(Error)
A zlib (de)compression error occurred.