Module packets

Module packets 

Wire representations of the SOE protocol packets, with (de)serialization.

Two categories of packet exist:

Structs

Acknowledge
A packet used to acknowledge a single data sequence. Serialized without OP code.
AcknowledgeAll
A packet used to acknowledge all sequences up to and including sequence. Serialized without OP code.
Disconnect
A packet used to terminate a session. Serialized without OP code or CRC.
RemapConnection
A packet used to remap an existing session to a new port.
SessionRequest
A packet used to request the start of a session.
SessionResponse
A packet used to confirm a session request.
UnknownSender
A packet indicating the receiver has no session for the sender’s address. Carries no fields beyond its OP code.

Functions

session_request
Constructs a SessionRequest using this crate’s protocol version.