pub struct SessionRequest {
pub soe_protocol_version: u32,
pub session_id: u32,
pub udp_length: u32,
pub application_protocol: String,
}Expand description
A packet used to request the start of a session.
Fields
soe_protocol_version: u32The version of the SOE protocol in use.
session_id: u32A randomly generated session identifier.
udp_length: u32The maximum length of a UDP packet that the sender can receive.
application_protocol: StringThe application protocol that the sender wishes to transport.
Implementations
Sourceimpl SessionRequest
impl SessionRequest
Sourcepub fn deserialize(buffer: &[u8], has_op_code: bool) -> Result<Self>
pub fn deserialize(buffer: &[u8], has_op_code: bool) -> Result<Self>
Deserializes a packet from buffer.