#[repr(u16)]pub enum DisconnectReason {
Show 17 variants
None = 0,
IcmpError = 1,
Timeout = 2,
OtherSideTerminated = 3,
ManagerDeleted = 4,
ConnectFail = 5,
Application = 6,
UnreachableConnection = 7,
UnacknowledgedTimeout = 8,
NewConnectionAttempt = 9,
ConnectionRefused = 10,
ConnectError = 11,
ConnectingToSelf = 12,
ReliableOverflow = 13,
ApplicationReleased = 14,
CorruptPacket = 15,
ProtocolMismatch = 16,
}Expand description
The possible session termination reasons.
Variants
None = 0
No reason can be given for the disconnect.
IcmpError = 1
An ICMP error occurred, forcing the disconnect.
Timeout = 2
The other party has let the session become inactive.
OtherSideTerminated = 3
Internal: the other party has sent a disconnect.
ManagerDeleted = 4
The session manager has been disposed of (e.g. shutting down).
ConnectFail = 5
Internal: a session request attempt has failed.
Application = 6
The application is terminating the session.
UnreachableConnection = 7
Internal: the other party is unreachable.
UnacknowledgedTimeout = 8
A data sequence was not acknowledged quickly enough.
NewConnectionAttempt = 9
A session request failed; a new attempt should be made after a short delay.
ConnectionRefused = 10
The application did not accept a session request.
ConnectError = 11
The proper session negotiation flow has not been observed.
ConnectingToSelf = 12
A session request was probably looped back to the sender.
ReliableOverflow = 13
Reliable data is being sent too fast to be processed.
ApplicationReleased = 14
The session manager has been orphaned by the application.
CorruptPacket = 15
A corrupt packet was received.
ProtocolMismatch = 16
The requested SOE protocol version or application protocol is invalid.
Implementations
Sourceimpl DisconnectReason
impl DisconnectReason
Sourcepub fn from_u16(value: u16) -> Self
pub fn from_u16(value: u16) -> Self
Converts a raw u16 into a DisconnectReason, mapping unrecognized
values to DisconnectReason::None.