OpCode

Enum OpCode 

#[repr(u16)]
pub enum OpCode {
Show 13 variants SessionRequest = 1, SessionResponse = 2, MultiPacket = 3, Disconnect = 5, Heartbeat = 6, NetStatusRequest = 7, NetStatusResponse = 8, ReliableData = 9, ReliableDataFragment = 13, Acknowledge = 17, AcknowledgeAll = 21, UnknownSender = 29, RemapConnection = 30,
}
The packet OP codes used in the SOE protocol. All packets are prefixed with a big-endian u16 OP code.

Variants



SessionRequest = 1

Used to request the start of a session.



SessionResponse = 2

Used to confirm the start of a session, and set connection details.



MultiPacket = 3

Used to encapsulate two or more SOE protocol packets.



Disconnect = 5

Used to indicate that a party is closing the session.



Heartbeat = 6

Used to keep a session alive when no data has been received for some time.



NetStatusRequest = 7

Network status request. Exact usage is not fully understood.



NetStatusResponse = 8

Network status response. Exact usage is not fully understood.



ReliableData = 9

Used to transfer small buffers of application data.



ReliableDataFragment = 13

Used to transfer large buffers of application data in multiple fragments.



Acknowledge = 17

Used to acknowledge a single reliable data packet.



AcknowledgeAll = 21

Used to acknowledge all reliable data packets up to a particular sequence.



UnknownSender = 29

Indicates the receiver has no session associated with the sender’s address.



RemapConnection = 30

Used to request that a session be remapped to another port.

Implementations

Source

impl OpCode

pub fn from_u16(value: u16) -> Option<Self>

Attempts to convert a raw u16 into an OpCode.

pub fn as_u16(self) -> u16

Returns the raw u16 value of this OP code.

pub fn is_contextless(self) -> bool

Returns true if this packet type is used outside of an established session context (and hence is not CRC-checked or compressed).