Module constants

Module constants 

Constant values and defaults used by this implementation of the SOE protocol.

Constants

CRC_LENGTH
The default number of bytes used to store the CRC check value of a packet.
DEFAULT_SESSION_HEARTBEAT_AFTER
The default duration after which to send a heartbeat, if no contextual packets have been received within the interval.
DEFAULT_SESSION_INACTIVITY_TIMEOUT
The default duration after which to consider a session inactive, if no contextual packets have been received within the interval.
DEFAULT_UDP_LENGTH
The default maximum packet (UDP) length.
MULTI_DATA_INDICATOR
The byte sequence that indicates a reliable data packet is carrying bundled (“multi”) data.
SOE_PROTOCOL_VERSION
The implemented version of the SOE protocol.