Wire representations of the SOE protocol packets, with (de)serialization.
Two categories of packet exist:
- Session-control packets (e.g.
SessionRequest,SessionResponse,RemapConnection,UnknownSender) embed their own OP code. Theirserializewrites the OP code, anddeserializetakes ahas_op_codeflag. - Session-context packets (e.g.
Disconnect,Acknowledge,AcknowledgeAll) are written without an OP code or CRC; those are added by the contextual packet wrapper.
Structs
- Acknowledge
- A packet used to acknowledge a single data sequence. Serialized without OP code.
- Acknowledge
All - A packet used to acknowledge all sequences up to and including
sequence. Serialized without OP code. - Disconnect
- A packet used to terminate a session. Serialized without OP code or CRC.
- Remap
Connection - A packet used to remap an existing session to a new port.
- Session
Request - A packet used to request the start of a session.
- Session
Response - A packet used to confirm a session request.
- Unknown
Sender - A packet indicating the receiver has no session for the sender’s address. Carries no fields beyond its OP code.
Functions
- session_
request - Constructs a
SessionRequestusing this crate’s protocol version.