SessionParameters

Struct SessionParameters 

pub struct SessionParameters {
Show 13 fields pub application_protocol: String, pub udp_length: u32, pub remote_udp_length: u32, pub crc_seed: u32, pub crc_length: u8, pub is_compression_enabled: bool, pub max_queued_incoming_reliable: u16, pub max_queued_outgoing_reliable: u16, pub data_ack_window: u16, pub heartbeat_after: Duration, pub inactivity_timeout: Duration, pub acknowledge_all_data: bool, pub max_ack_delay: Duration,
}
Parameters controlling a session. Mutated during negotiation as the two parties agree on connection details.

Fields

application_protocol: String

The application protocol being proxied (must match between the two parties).

udp_length: u32

The maximum UDP payload length this party can receive.

remote_udp_length: u32

The maximum UDP payload length the remote party can receive.

crc_seed: u32

The seed used to compute packet CRCs (agreed during negotiation).

crc_length: u8

The number of bytes used to store a packet CRC (0..=4).

is_compression_enabled: bool

Whether contextual packets may be compressed.

max_queued_incoming_reliable: u16

The maximum number of incoming reliable data packets that may be queued.

max_queued_outgoing_reliable: u16

The maximum number of outgoing reliable data packets in flight at once.

data_ack_window: u16

The acknowledgement window used by the input channel.

heartbeat_after: Duration

The interval after which to send a heartbeat (client only). ZERO disables.

inactivity_timeout: Duration

The interval after which to terminate an inactive session. ZERO disables.

acknowledge_all_data: bool

Whether every incoming reliable data packet is acknowledged individually.

max_ack_delay: Duration

The maximum delay before acknowledging incoming reliable data sequences.